@@ -26,5 +26,8 @@
  * $FANOUT_END_LICENSE$
  */
 
+pub mod ffi;
+pub mod list;
 pub mod publish_cli;
+pub mod timer;
 pub mod tnetstring;
